"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useKeyboard = void 0;

var _react = require("react");

var _reactNative = require("react-native");

const useKeyboard = () => {
  const [keyboardVisible, setKeyboardVisible] = (0, _react.useState)(false);
  const [keyboardHeight, setKeyboardHeight] = (0, _react.useState)(0);

  function onKeyboardDidShow(e) {
    setKeyboardHeight(e.endCoordinates.height);
    setKeyboardVisible(true);
  }

  function onKeyboardDidHide() {
    setKeyboardHeight(0);
    setKeyboardVisible(false);
  }

  (0, _react.useEffect)(() => {
    const showSubscription = _reactNative.Keyboard.addListener('keyboardWillShow', onKeyboardDidShow);

    const hideSubscription = _reactNative.Keyboard.addListener('keyboardWillHide', onKeyboardDidHide);

    return () => {
      showSubscription.remove();
      hideSubscription.remove();
    };
  }, []);
  return {
    keyboardVisible,
    keyboardHeight
  };
};

exports.useKeyboard = useKeyboard;
//# sourceMappingURL=useKeyboard.js.map